@@ -1,4 +1,4 @@
-__version__ = '0.0.1'
+__version__ = '0.0.3'
 
 ## Import packages
 import numpy as np
@@ -7,21 +7,6 @@ from scipy import signal
 import matplotlib.pyplot as plt
 from sklearn.model_selection import KFold
 ## Convenience functions
-k2sd = lambda k : np.sqrt( -2 * np.log( sp.special.iv(1,k) / sp.special.iv(0,k) ) )
-def sd2k(S):
-    try:
-        len(S)
-    except:
-        S = np.array([S])
-    R = np.exp(-S**2/2)
-    K = 1/(R**3 - 4 * R**2 + 3 * R)
-    if np.any(R < 0.85):
-        K[R < 0.85] = -0.4 + 1.39 * R[R < 0.85] + 0.43/(1 - R[R < 0.85])
-    if np.any(R < 0.53):
-        K[R < 0.53] = 2 * R[R < 0.53] + R[R < 0.53]**3 + (5 * R[R < 0.53]**5)/6
-    if len(S) == 1:
-        K = float(K)
-    return K
 def normalize(x):
     return (x-np.min(x))/(np.max(x)-np.min(x))
 def make_gaussian_iter(mu,sd,stim_max=360):
@@ -95,14 +80,14 @@ def IEM(trialbyvoxel,features,stim_max=180,is_circular=True,nfolds=10,
 
     Parameters
     ----------
-    trialbyvoxel : matrix
+    trialbyvoxel : matrix (ndarray)
         A matrix of brain activations with shape num_trials by num_voxels (or num_electrodes/num_components/etc.)
     features : int, array
         The stimulus features for every trial, in the same order as the trials specified by trialbyvoxel. All features must be within the range of stimulus space specified by stim_max. All features will be converted to integers if not already.
     stim_max : int, optional
         Specifies the range of stimulus space, such that all features are assumed to be within the range of zero to stim_max-1. E.g., if studying color within a 360° stimulus space, you must change this value to 360 and ensure that all features are integers within 0-359. Defaults to 0-179° stimulus space.
     is_circular: bool, optional
-        Specifies whether the stimulus space is circular or not. Defaults to True. E.g., for orientation and color, stimulus space is typically circular (170° and 0° are the same distance away from 180°, assuming stim_max=180); however, for spatial location, you would typically not want a circular stimulus space. 
+        Specifies whether the stimulus space is circular or not. Defaults to True. E.g., for orientation and color, stimulus space is typically circular (170° and 0° are the same distance away from 175°, assuming stim_max=180); however, for spatial location, you would typically not want a circular stimulus space. 
     nfolds : int, optional
         Number of folds of cross-validation. Defaults to 10.
     nchannels : int, optional
@@ -133,7 +118,8 @@ def IEM(trialbyvoxel,features,stim_max=180,is_circular=True,nfolds=10,
     ntrials = len(features)
     
     # ensure stimulus features are integers less than stim_max
-    features = features.astype(int)
+    if not issubclass(features, np.integer):
+        raise Exception('All features must be integers within range 0 to stim_max-1. If your stimulus space requires decimal precision, you can multiply your array by some order of magnitude, run this function, and then undo the transformation afterwards.')
     if is_circular:
         features[features==stim_max]=0
     elif np.max(features)==stim_max:
